# Striplog

[![Build and test](https://github.com/agile-geoscience/striplog/actions/workflows/run-tests.yml/badge.svg)](https://github.com/agile-geoscience/striplog/actions/workflows/run-tests.yml)
[![Build docs](https://github.com/agile-geoscience/striplog/actions/workflows/build-docs.yml/badge.svg)](https://github.com/agile-geoscience/striplog/actions/workflows/build-docs.yml)
[![PyPI version](https://img.shields.io/pypi/v/striplog.svg)](https://pypi.org/project/striplog/)
[![PyPI versions](https://img.shields.io/pypi/pyversions/striplog.svg)](https://pypi.org/project/striplog/)
[![PyPI license](https://img.shields.io/pypi/l/striplog.svg)](https://pypi.org/project/striplog/)

Lithology and stratigraphic logs for wells and outcrop.

* [A blog post about striplog](http://www.agilegeoscience.com/blog/2015/4/15/striplog)
* [Another one, with a video](http://www.agilegeoscience.com/blog/2015/7/10/geophysics-at-scipy-2015)


## Install

* `pip install striplog`

We recommend setting up a virtual environment:

* Install Anaconda if you don't have it already
* Then create an environment called `myenv` (or whatever you like):

    conda create -n myenv python=3.9 numpy scipy matplotlib
    conda activate myenv

* Then you can do:

    pip install striplog


## Docs

[Read striplog's documentation.](https://code.agilescientific.com/striplog)
